Module: Webhooks::Outgoing::TeamSupport

Extended by:
ActiveSupport::Concern
Defined in:
app/models/concerns/webhooks/outgoing/team_support.rb

Instance Method Summary collapse

Instance Method Details

#mark_for_destructionObject



11
12
13
14
# File 'app/models/concerns/webhooks/outgoing/team_support.rb', line 11

def mark_for_destruction
  # This allows downstream logic to check whether a team is being destroyed in order to bypass webhook issuance.
  update_column(:being_destroyed, true)
end